@@ -220,7 +220,7 @@
 #'
 #' Andrew D. Martin, Kevin M. Quinn, and Jong Hee Park. 2011.  ``MCMCpack:
 #' Markov Chain Monte Carlo in R.'', \emph{Journal of Statistical Software}.
-#' 42(9): 1-21.  \url{http://www.jstatsoft.org/v42/i09/}.
+#' 42(9): 1-21.  \doi{10.18637/jss.v042.i09}.
 #'
 #' M. K. Cowles. 1996. ``Accelerating Monte Carlo Markov Chain Convergence for
 #' Cumulative-link Generalized Linear Models." \emph{Statistics and Computing.}
@@ -230,7 +230,7 @@
 #' Springer: New York.
 #'
 #' Daniel Pemstein, Kevin M. Quinn, and Andrew D. Martin.  2007.  \emph{Scythe
-#' Statistical Library 1.0.} \url{http://scythe.wustl.edu}.
+#' Statistical Library 1.0.} \url{http://scythe.lsa.umich.edu}.
 #'
 #' Martyn Plummer, Nicky Best, Kate Cowles, and Karen Vines. 2006.  ``Output
 #' Analysis and Diagnostics for MCMC (CODA)'', \emph{R News}. 6(1): 7-11.
@@ -591,8 +591,7 @@
     rownames(accepts) <- X.names
     colnames(accepts) <- ""
     cat("\n\nAcceptance rates:\n")
-    print(t(accepts) / (posterior$burnin+posterior$mcmc), digits=2,
-          width=6)
+    print(t(accepts) / (posterior$burnin+posterior$mcmc), digits=2)
 
     # put together matrix and build MCMC object to return
     sample <- matrix(posterior$samdata, posterior$samrow, posterior$samcol,
